<?php

namespace Drupal\purge_file\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure Purge file settings for this site.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * Used to get the processors option list.
   *
   * @var \Drupal\purge\Plugin\Purge\Processor\ProcessorsServiceInterface
   */
  protected $purgeProcessors;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->purgeProcessors = $container->get('purge.processors');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'purge_file_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['purge_file.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $enabled_processors = $this->processorsOptionList();
    $form['processor'] = [
      '#type' => 'select',
      '#title' => $this->t('Processor'),
      '#description' => $this->t('The purge processor that will be used to purge the updated / deleted files.'),
      '#default_value' => $this->config('purge_file.settings')->get('processor'),
      '#options' => $enabled_processors,
      '#disabled' => empty($enabled_processors),
      '#required' => TRUE,
    ];

    if (empty($enabled_processors)) {
      $form['processors_unavailable'] = [
        '#type' => 'item',
        '#markup' => $this->t('No processors available. Please enable a purge processor to your site to make the module works.'),
      ];
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * List of processors that can be selected to purge the files.
   *
   * @return array
   *   Key-value of respective plugin id and plugin label.
   */
  protected function processorsOptionList() {
    $processors_enabled = $this->purgeProcessors->getPluginsEnabled();
    $processors_list = [];
    foreach ($processors_enabled as $processor_id) {
      $processors_list[$processor_id] = $this->purgeProcessors->get($processor_id)->getLabel();
    }
    return $processors_list;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('purge_file.settings')
      ->set('processor', $form_state->getValue('processor'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
